mathtools.partition_integer_into_parts_less_than_double
=======================================================

.. autofunction:: abjad.tools.mathtools.partition_integer_into_parts_less_than_double.partition_integer_into_parts_less_than_double
